Learn R Programming

NCIgraph (version 1.20.0)

NCI.demo.cyList: 10 raw NCI networks from Nature curated pathways and BioCarta imported as graphNEL objects, for demonstration purpose

Description

These are the ten first elements of the full list of raw networks that can be downloaded using the downloadCyLists.R script.

Usage

NCI.demo.cyList

Arguments

Format

A list of 10 graphNEL objects.

Examples

Run this code
data("NCIgraphVignette")
length(NCI.demo.cyList)

library(Rgraphviz)
plot(NCI.demo.cyList[[1]])

Run the code above in your browser using DataLab