mergeNodes: Merges a given list of nodes in a graph
Description
Merges a given list of nodes in a graph.
Usage
mergeNodes(g, mEdges, separateEntrez=TRUE, entrezOnly=TRUE)
Arguments
mEdges
A list of nodes to be merged. separateEntrez
A logical. If TRUE, don't merge two nodes with entrezID. entrezOnly
A logical. If TRUE, only keep nodes with an entrezID property.